# Embedding files of Diagrams.net (Draw.io) into MkDocs

[![](https://github.com/onixpro/mkdocs-drawio-file/workflows/Deploy/badge.svg)](https://github.com/onixpro/mkdocs-drawio-file/actions)
[![PyPI](https://img.shields.io/pypi/v/mkdocs-drawio-file)](https://pypi.org/project/mkdocs-drawio-file/)



[Buy me a 🍜](https://www.buymeacoffee.com/SergeyLukin)

## Features

With the plugin configured, you can now proceed to embed images by simply embedding the `*.drawio` diagram file as you would with any image file:

```markdown
![My alt text](my-diagram.drawio)
```


## Dependencies

## Setup

Install plugin using pip:

```
pip install mkdocs-drawio-file
```

Next, add the plugin to your `mkdocs.yml`

```yaml
plugins:
  - drawio_file
```
